==> openshift-model-tuned-5.12.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/ProfileStatusBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProfileStatusBuilder extends io.fabric8.openshift.api.model.tuned.v1.ProfileStatusFluentImpl<io.fabric8.openshift.api.model.tuned.v1.ProfileStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.tuned.v1.ProfileStatus,io.fabric8.openshift.api.model.tuned.v1.ProfileStatusBuilder>{
  public ProfileStatusBuilder() {
    this(false);
  }
  public ProfileStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new ProfileStatus(), validationEnabled);
  }
  public ProfileStatusBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ProfileStatusBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProfileStatus(), validationEnabled);
  }
  public ProfileStatusBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.ProfileStatus instance) {
    this(fluent, instance, false);
  }
  public ProfileStatusBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileStatusFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.ProfileStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBootcmdline(instance.getBootcmdline()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withStalld(instance.getStalld()); 
    fluent.withTunedProfile(instance.getTunedProfile()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProfileStatusBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileStatus instance) {
    this(instance,false);
  }
  public ProfileStatusBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBootcmdline(instance.getBootcmdline()); 
    this.withConditions(instance.getConditions()); 
    this.withStalld(instance.getStalld()); 
    this.withTunedProfile(instance.getTunedProfile()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.tuned.v1.ProfileStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.tuned.v1.ProfileStatus build() {
    ProfileStatus buildable = new ProfileStatus(fluent.getBootcmdline(),fluent.getConditions(),fluent.getStalld(),fluent.getTunedProfile());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProfileStatusBuilder that = (ProfileStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-tuned-6.5.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/ProfileStatusBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ProfileStatusBuilder extends ProfileStatusFluentImpl<ProfileStatusBuilder> implements VisitableBuilder<ProfileStatus,ProfileStatusBuilder>{
  public ProfileStatusBuilder() {
    this(false);
  }
  public ProfileStatusBuilder(Boolean validationEnabled) {
    this(new ProfileStatus(), validationEnabled);
  }
  public ProfileStatusBuilder(ProfileStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ProfileStatusBuilder(ProfileStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ProfileStatus(), validationEnabled);
  }
  public ProfileStatusBuilder(ProfileStatusFluent<?> fluent,ProfileStatus instance) {
    this(fluent, instance, false);
  }
  public ProfileStatusBuilder(ProfileStatusFluent<?> fluent,ProfileStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBootcmdline(instance.getBootcmdline()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withStalld(instance.getStalld()); 
    fluent.withTunedProfile(instance.getTunedProfile()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProfileStatusBuilder(ProfileStatus instance) {
    this(instance,false);
  }
  public ProfileStatusBuilder(ProfileStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBootcmdline(instance.getBootcmdline()); 
    this.withConditions(instance.getConditions()); 
    this.withStalld(instance.getStalld()); 
    this.withTunedProfile(instance.getTunedProfile()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ProfileStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ProfileStatus build() {
    ProfileStatus buildable = new ProfileStatus(fluent.getBootcmdline(),fluent.getConditions(),fluent.getStalld(),fluent.getTunedProfile());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
